/**			UIManager Class
 * This class creates a user interface where vertical axis represents indtruments and horizontal access represents time.
 */

import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;

/**@author Dani Odicho */
public class UIManager implements ItemListener
{
  public JFrame frame;
  private int Instruments;
  public JLabel labels[];
  private boolean[][] checkBoxes;
  private JCheckBox[][] cb;
  private int timeSections;
  Main m;
  
  /** Instantiates a User Interface.
	 @param main an instance of main.
	 @param rows number of rows that represents the number of instruments in the user interface.
	 @param columns number of check boxes for each instruments.
	 */
  public UIManager(Main main, int rows, int columns)
  {
    setInstruments(rows);
    setSections(columns);
    cb = new JCheckBox[getInstruments()][getSections()];
    checkBoxes = new boolean[getInstruments()][getSections()];
    labels = new JLabel[getInstruments()];
    createUI();
    setMain(main);
    
  }
  
  public void setMain(Main newMain)
  {
    this.m = newMain;
  }
  public void setLabel(String title , int index ){
	  labels[index].setText(title);
  }
  
  public String getLabel(int index){
	 return labels[index].getText();
  }
  
  /** Changes the labels next to the check boxes to the instrument names.
	 @param newTitles array of Strings that contains the instrument names.
	 */
  public void setLabels(String[] newTitles){
	  try{
	  for(int i = 0; i<labels.length;i++){
		  labels[i].setText(newTitles[i]);
	  }
  }catch( ArrayIndexOutOfBoundsException e){ System.out.println("Error: Make sure you have enough labels in your array.");}
  }
  
  public void setInstruments(int value){
	  Instruments = value;
  }
  
  public int getInstruments(){
	  return Instruments;
  }
  
  public void setSections(int value){
	  timeSections = value;
  }
  
  public int getSections(){
	  return timeSections;
  }
  /**return the values of all the check boxes on the user interface.
	 @return a two dimensional boolean array that holds the values of the check boxes .
	 */
  boolean[][] getArrayofCheckBoxes(){
	  return checkBoxes;
  }
  
  private void createUI()
  {
    this.frame = new JFrame("Beats");
    JPanel jPanel1;
    JScrollPane jScrollPane1;

        jPanel1 = new JPanel();
        jPanel1.setLayout(new GridLayout(0, timeSections+1, 10, 10));
        jScrollPane1 = new JScrollPane(jPanel1);
    
   for(int j = 0; j < getInstruments() ; j++){
	   labels[j] = new JLabel("Instrument"+j);
	    jPanel1.add(labels[j]);
   for (int index = 0;index<getSections();index++){
	   
    cb[j][index] = new JCheckBox();
    cb[j][index].addItemListener(this);
    jPanel1.add(cb[j][index]);

    }
   }
   jPanel1.revalidate();

   jPanel1.repaint();
   frame.add(jScrollPane1);


    JButton btn = new JButton("Play");
   	for(int i = 0;i<=timeSections; i++){
   		if ((timeSections%2==0)&&(i==(timeSections/2)) || ((timeSections%2==1)&&(i==(timeSections-1/2)))){
   			jPanel1.add(btn);
   		}
   		else{
   			JLabel blank = new JLabel("");
   			jPanel1.add(blank);
   		}
   	}
    
    
    btn.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      {
        new Thread(new Runnable()
        {
          public void run() {
        	  m.PlayButtonClicked();
          }
        })
          .start();
      }
    });
    
    
    this.frame.setDefaultCloseOperation(3);
    this.frame.pack();
    this.frame.setVisible(true);
  


	
	  }
	  
	@Override
	public void itemStateChanged(ItemEvent arg0) {
		// TODO Auto-generated method stub
		for(int j = 0; j < getInstruments() ; j++){
		  for (int index = 0;index<getSections();index++){
		if(cb[j][index].isSelected()){
			checkBoxes[j][index] = true;
			//m.printAll();
		}
		else
			checkBoxes[j][index] = false;
		  }
	}
	
	}
	  

}
